@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -37,34 +37,35 @@
 
 static void
 parole_dialog_show (GtkWindow *parent, 
-		    GtkMessageType type,
-		    const gchar *window_title,
-		    const gchar *title, 
-		    const gchar *msg)
+                    GtkMessageType type,
+                    const gchar *window_title,
+                    const gchar *title, 
+                    const gchar *msg)
 {
     GtkWidget *dialog;
     
     dialog = gtk_message_dialog_new_with_markup (parent,
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 type,
-						 GTK_BUTTONS_CLOSE,
-						 "<span size='larger'><b>%s</b></span>",
-						 title);
-						 
+                        GTK_DIALOG_DESTROY_WITH_PARENT,
+                        type,
+                        GTK_BUTTONS_CLOSE,
+                        "<span size='larger'><b>%s</b></span>",
+                        title);
+                         
     gtk_window_set_title (GTK_WINDOW (dialog), window_title);
+    gtk_window_set_icon_name (GTK_WINDOW (dialog), "parole");
     
     gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), "%s", msg);
 
 
-    g_signal_connect_swapped (dialog,
-			      "response",
-			      G_CALLBACK (gtk_widget_destroy),
-			      dialog);
+    g_signal_connect_swapped   (dialog,
+                                "response",
+                                G_CALLBACK (gtk_widget_destroy),
+                                dialog);
 
     gtk_widget_show_all (dialog);
 }
 
-void parole_dialog_info	(GtkWindow *parent, const gchar *title,	const gchar *msg)
+void parole_dialog_info (GtkWindow *parent, const gchar *title, const gchar *msg)
 {
     parole_dialog_show (parent, GTK_MESSAGE_INFO, _("Message"), title, msg);
 }
@@ -75,21 +76,22 @@ void parole_dialog_error (GtkWindow *parent, const gchar *title, const gchar *ms
 }
 
 
-void parole_window_busy_cursor		(GdkWindow *window)
+void parole_window_busy_cursor (GdkWindow *window)
 {
     GdkCursor *cursor;
     
     if ( G_UNLIKELY (window == NULL) )
-	return;
-	
+        return;
+    
     cursor = gdk_cursor_new (GDK_WATCH);
     gdk_window_set_cursor (window, cursor);
-    gdk_cursor_unref (cursor);
+    
+    g_object_unref (cursor);
 
     gdk_flush ();
 }
 
-void parole_window_invisible_cursor		(GdkWindow *window)
+void parole_window_invisible_cursor (GdkWindow *window)
 {
     GdkCursor *cursor = NULL;
 
@@ -97,11 +99,6 @@ void parole_window_invisible_cursor		(GdkWindow *window)
 
     gdk_window_set_cursor (window, cursor);
 
-    if (cursor) {
-#if GTK_CHECK_VERSION(3, 0, 0)
-	g_object_unref (cursor);
-#else
-	gdk_cursor_unref (cursor);
-#endif
-    }
+    if (cursor)
+        g_object_unref (cursor);
 }
