@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -51,7 +51,6 @@ enum
     PROP_VIS_NAME,
     PROP_VOLUME,
     /* Folders */
-    PROP_ISO_IMAGE_FOLDER,
     PROP_MEDIA_CHOOSER_FOLDER,
     /* Parole General */
     PROP_MULTIMEDIA_KEYS,
@@ -79,7 +78,8 @@ enum
     PROP_SATURATION,
     /* Window properties */
     PROP_WINDOW_HEIGHT,
-    PROP_MINIMIZED,
+    PROP_WINDOW_MAXIMIZED,
+    PROP_WINDOW_MINIMIZED,
     PROP_WINDOW_WIDTH,
     N_PROP
 };
@@ -91,6 +91,8 @@ static void parole_conf_get_property    (GObject        *object,
                                          guint           prop_id,
                                          GValue         *value,
                                          GParamSpec     *pspec);
+gchar
+*parole_conf_map_xfconf_property_name   (const gchar *prop_name);
 static void parole_conf_set_property    (GObject        *object,
                                          guint           prop_id,
                                          const GValue   *value,
@@ -150,7 +152,7 @@ static void parole_conf_set_property (GObject *object,
 
     /* leave if the channel is not set */
     if (G_UNLIKELY (conf->channel == NULL))
-    return;
+        return;
 
     /* build property name */
     g_snprintf (prop_name, sizeof (prop_name), "/%s", g_param_spec_get_name (pspec));
@@ -186,6 +188,21 @@ static void parole_conf_set_property (GObject *object,
 
     /* thaw */
     g_signal_handler_unblock (conf->channel, conf->property_changed_id);
+
+    /* now we can notify the plugins */
+    switch(prop_id)
+    {
+       /* sadly this one recurses */
+       case PROP_VOLUME:
+       break;
+
+       /* these can be consumed by plugins */
+       /* case PROP_SHUFFLE: */
+       /* case PROP_REPEAT: */
+       default:
+       parole_conf_prop_changed(conf->channel, xfconf_nick, value, conf);
+       break;
+    }
 }
 
 /**
@@ -242,6 +259,69 @@ static void parole_conf_get_property (GObject *object,
     }
 }
 
+/* Facilitate the conversion from xfconf property name to parole property name */
+gchar *parole_conf_map_xfconf_property_name (const gchar *prop_name)
+{
+    gchar *value = NULL;
+    if (g_strcmp0(prop_name, "/audio/visualization-enabled") == 0)
+        value = g_strdup("vis-enabled");
+    if (g_strcmp0(prop_name, "/audio/visualization-name") == 0)
+        value = g_strdup("vis-name");
+    if (g_strcmp0(prop_name, "/audio/volume") == 0)
+        value = g_strdup("volume");
+    if (g_strcmp0(prop_name, "/folders/last-used-media") == 0)
+        value = g_strdup("media-chooser-folder");
+    if (g_strcmp0(prop_name, "/parole/multimedia-keys") == 0)
+        value = g_strdup("multimedia-keys");
+    if (g_strcmp0(prop_name, "/parole/plugins") == 0)
+        value = g_strdup("plugins");
+    if (g_strcmp0(prop_name, "scan-recursive") == 0)
+        value = g_strdup("/parole/scan-recursive");
+    if (g_strcmp0(prop_name, "/playlist/remember-playlist") == 0)
+        value = g_strdup("remember-playlist");
+    if (g_strcmp0(prop_name, "/playlist/remove-duplicates") == 0)
+        value = g_strdup("remove-duplicated");
+    if (g_strcmp0(prop_name, "/playlist/repeat") == 0)
+        value = g_strdup("repeat");
+    if (g_strcmp0(prop_name, "/playlist/replace-playlist") == 0)
+        value = g_strdup("replace-playlist");
+    if (g_strcmp0(prop_name, "/playlist/show-playlist") == 0)
+        value = g_strdup("showhide-playlist");
+    if (g_strcmp0(prop_name, "/playlist/shuffle") == 0)
+        value = g_strdup("shuffle");
+    if (g_strcmp0(prop_name, "/playlist/play-opened-files") == 0)
+        value = g_strdup("play-opened-files");
+    if (g_strcmp0(prop_name, "/subtitles/enabled") == 0)
+        value = g_strdup("enable-subtitle");
+    if (g_strcmp0(prop_name, "/subtitles/encoding") == 0)
+        value = g_strdup("subtitle-encoding");
+    if (g_strcmp0(prop_name, "/subtitles/font") == 0)
+        value = g_strdup("subtitle-font");
+    if (g_strcmp0(prop_name, "/video/aspect-ratio") == 0)
+        value = g_strdup("aspect-ratio");
+    if (g_strcmp0(prop_name, "/video/brightness") == 0)
+        value = g_strdup("brightness");
+    if (g_strcmp0(prop_name, "/video/contrast") == 0)
+        value = g_strdup("contrast");
+    if (g_strcmp0(prop_name, "/video/disable-screensaver") == 0)
+        value = g_strdup("reset-saver");
+    if (g_strcmp0(prop_name, "/video/enable-xv") == 0)
+        value = g_strdup("enable-xv");
+    if (g_strcmp0(prop_name, "/video/hue") == 0)
+        value = g_strdup("hue");
+    if (g_strcmp0(prop_name, "/video/saturation") == 0)
+        value = g_strdup("saturation");
+    if (g_strcmp0(prop_name, "/window/height") == 0)
+        value = g_strdup("window-height");
+    if (g_strcmp0(prop_name, "/window/minimized") == 0)
+        value = g_strdup("minimized");
+    if (g_strcmp0(prop_name, "/window/maximized") == 0)
+        value = g_strdup("window-maximized");
+    if (g_strcmp0(prop_name, "/window/width") == 0)
+        value = g_strdup("window-width");
+    return value;
+}
+
 /**
  * parole_conf_prop_changed:
  * @channel   : the #XfconfChannel where settings are stored.
@@ -259,9 +339,11 @@ static void parole_conf_prop_changed    (XfconfChannel  *channel,
     GParamSpec *pspec;
 
     /* check if the property exists and emit change */
-    pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (conf), prop_name + 1);
+    pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (conf), parole_conf_map_xfconf_property_name(prop_name));
     if (G_LIKELY (pspec != NULL))
         g_object_notify_by_pspec (G_OBJECT (conf), pspec);
+
+    g_debug("Propchange:%s,%p", prop_name, pspec);
 }
 
 /**
@@ -348,13 +430,13 @@ parole_conf_class_init (ParoleConfClass *klass)
     object_class->set_property = parole_conf_set_property;
 
     if (!g_value_type_transformable (G_TYPE_STRING, G_TYPE_INT))
-    g_value_register_transform_func (G_TYPE_STRING, G_TYPE_INT, transform_string_to_int);
+        g_value_register_transform_func (G_TYPE_STRING, G_TYPE_INT, transform_string_to_int);
 
     if (!g_value_type_transformable (G_TYPE_STRING, G_TYPE_BOOLEAN))
-    g_value_register_transform_func (G_TYPE_STRING, G_TYPE_BOOLEAN, transform_string_to_boolean);
+        g_value_register_transform_func (G_TYPE_STRING, G_TYPE_BOOLEAN, transform_string_to_boolean);
     
     if (!g_value_type_transformable (G_TYPE_STRING, GST_ENUM_TYPE_ASPECT_RATIO))
-    g_value_register_transform_func (G_TYPE_STRING, GST_ENUM_TYPE_ASPECT_RATIO, transform_string_to_enum);
+        g_value_register_transform_func (G_TYPE_STRING, GST_ENUM_TYPE_ASPECT_RATIO, transform_string_to_enum);
 
     /**
      * ParoleConf:vis-enabled:
@@ -381,10 +463,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_VIS_NAME,
                                      g_param_spec_string  ("vis-name",
-                                                           "/audio/visualization-name", 
-                                                           NULL,
-                                                           "none",
-                                                           G_PARAM_READWRITE));
+                                            "/audio/visualization-name", 
+                                            NULL,
+                                            "none",
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:volume:
@@ -396,27 +478,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_VOLUME,
                                      g_param_spec_int ("volume",
-                                                       "/audio/volume", 
-                                                       NULL,
-                                                       0,
-                                                       100,
-                                                       50,
-                                                       G_PARAM_READWRITE));
-
-    /**
-     * ParoleConf:iso-image-folder:
-     *
-     * Xfconf property: /folders/last-used-iso
-     *
-     * Path to directory containing last used iso image.
-     **/
-    g_object_class_install_property (object_class,
-                                     PROP_ISO_IMAGE_FOLDER,
-                                     g_param_spec_string  ("iso-image-folder",
-                                                           "/folders/last-used-iso", 
-                                                           NULL,
-                                                           "none",
-                                                           G_PARAM_READWRITE));
+                                            "/audio/volume", 
+                                            NULL,
+                                            0,
+                                            100,
+                                            50,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:media-chooser-folder:
@@ -428,10 +495,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_MEDIA_CHOOSER_FOLDER,
                                      g_param_spec_string  ("media-chooser-folder",
-                                                           "/folders/last-used-media", 
-                                                           NULL,
-                                                           "none",
-                                                           G_PARAM_READWRITE));
+                                            "/folders/last-used-media", 
+                                            NULL,
+                                            "none",
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:multimedia-keys:
@@ -443,10 +510,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_MULTIMEDIA_KEYS,
                                      g_param_spec_boolean ("multimedia-keys",
-                                                           "/parole/multimedia-keys", 
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/parole/multimedia-keys", 
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:plugins:
@@ -458,10 +525,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_PLUGINS,
                                      g_param_spec_string  ("plugins",
-                                                           "/parole/plugins", 
-                                                           NULL,
-                                                           "none",
-                                                           G_PARAM_READWRITE));
+                                            "/parole/plugins", 
+                                            NULL,
+                                            "none",
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:scan-recursive:
@@ -473,10 +540,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SCAN_FOLDER_RECURSIVELY,
                                      g_param_spec_boolean ("scan-recursive",
-                                                           "/parole/scan-recursive", 
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/parole/scan-recursive", 
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:remember-playlist:
@@ -488,10 +555,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_REMEMBER_PLAYLIST,
                                      g_param_spec_boolean ("remember-playlist",
-                                                           "/playlist/remember-playlist", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/remember-playlist", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:remove-duplicated:
@@ -503,10 +570,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_REMOVE_DUPLICATED_PLAYLIST_ENTRIES,
                                      g_param_spec_boolean ("remove-duplicated",
-                                                           "/playlist/remove-duplicates", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/remove-duplicates", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:repeat:
@@ -518,10 +585,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_REPEAT,
                                      g_param_spec_boolean ("repeat",
-                                                           "/playlist/repeat", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/repeat", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:replace-playlist:
@@ -534,10 +601,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_REPLACE_PLAYLIST,
                                      g_param_spec_boolean ("replace-playlist",
-                                                           "/playlist/replace-playlist", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/replace-playlist", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:showhide-playlist:
@@ -549,10 +616,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SHOWHIDE_PLAYLIST,
                                      g_param_spec_boolean ("showhide-playlist",
-                                                           "/playlist/show-playlist", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/show-playlist", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:shuffle:
@@ -564,10 +631,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SHUFFLE,
                                      g_param_spec_boolean ("shuffle",
-                                                           "/playlist/shuffle", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/shuffle", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:play-opened-files:
@@ -580,10 +647,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_START_PLAYING_OPENED_FILES,
                                      g_param_spec_boolean ("play-opened-files",
-                                                           "/playlist/play-opened-files", 
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/playlist/play-opened-files", 
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:enable-subtitle:
@@ -595,10 +662,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SUBTITLE_ENABLED,
                                      g_param_spec_boolean ("enable-subtitle",
-                                                           "/subtitles/enabled", 
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/subtitles/enabled", 
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:subtitle-encoding:
@@ -610,10 +677,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SUBTITLE_ENCODING,
                                      g_param_spec_string  ("subtitle-encoding",
-                                                           "/subtitles/encoding", 
-                                                           NULL,
-                                                           "UTF-8",
-                                                           G_PARAM_READWRITE));
+                                            "/subtitles/encoding", 
+                                            NULL,
+                                            "UTF-8",
+                                            G_PARAM_READWRITE));
     
     /**
      * ParoleConf:subtitle-font:
@@ -625,10 +692,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SUBTITLE_FONT,
                                      g_param_spec_string  ("subtitle-font",
-                                                           "/subtitles/font", 
-                                                           NULL,
-                                                           "Sans Bold 20",
-                                                           G_PARAM_READWRITE));
+                                            "/subtitles/font", 
+                                            NULL,
+                                            "Sans Bold 20",
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:aspect-ratio:
@@ -640,11 +707,11 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_ASPECT_RATIO,
                                      g_param_spec_enum ("aspect-ratio",
-                                                        "/video/aspect-ratio", 
-                                                        NULL,
-                                                        GST_ENUM_TYPE_ASPECT_RATIO,
-                                                        PAROLE_ASPECT_RATIO_AUTO,
-                                                        G_PARAM_READWRITE));
+                                            "/video/aspect-ratio", 
+                                            NULL,
+                                            GST_ENUM_TYPE_ASPECT_RATIO,
+                                            PAROLE_ASPECT_RATIO_AUTO,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:brightness:
@@ -656,12 +723,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_BRIGHTNESS,
                                      g_param_spec_int ("brightness",
-                                                       "/video/brightness", 
-                                                       NULL,
-                                                       -1000,
-                                                       1000,
-                                                       0,
-                                                       G_PARAM_READWRITE));
+                                            "/video/brightness", 
+                                            NULL,
+                                            -1000,
+                                            1000,
+                                            0,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:contrast:
@@ -673,12 +740,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_CONTRAST,
                                      g_param_spec_int ("contrast",
-                                                       "/video/contrast", 
-                                                       NULL,
-                                                       -1000,
-                                                       1000,
-                                                       0,
-                                                       G_PARAM_READWRITE));
+                                            "/video/contrast", 
+                                            NULL,
+                                            -1000,
+                                            1000,
+                                            0,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:reset-saver:
@@ -690,10 +757,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_DISABLE_SCREEN_SAVER,
                                      g_param_spec_boolean ("reset-saver",
-                                                           "/video/disable-screensaver",
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/video/disable-screensaver",
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:enable-xv:
@@ -705,10 +772,10 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_ENABLE_XV,
                                      g_param_spec_boolean ("enable-xv",
-                                                           "/video/enable-xv", 
-                                                           NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
+                                            "/video/enable-xv", 
+                                            NULL,
+                                            TRUE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:hue:
@@ -720,12 +787,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_HUE,
                                      g_param_spec_int ("hue",
-                                                       "/video/hue", 
-                                                       NULL,
-                                                       -1000,
-                                                       1000,
-                                                       0,
-                                                       G_PARAM_READWRITE));
+                                            "/video/hue", 
+                                            NULL,
+                                            -1000,
+                                            1000,
+                                            0,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:saturation:
@@ -737,12 +804,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_SATURATION,
                                      g_param_spec_int ("saturation",
-                                                       "/video/saturation", 
-                                                       NULL,
-                                                       -1000,
-                                                       1000,
-                                                       0,
-                                                       G_PARAM_READWRITE));
+                                            "/video/saturation", 
+                                            NULL,
+                                            -1000,
+                                            1000,
+                                            0,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:window-height:
@@ -754,12 +821,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_WINDOW_HEIGHT,
                                      g_param_spec_int ("window-height",
-                                                       "/window/height", 
-                                                       NULL,
-                                                       1,
-                                                       G_MAXINT16,
-                                                       420,
-                                                       G_PARAM_READWRITE));
+                                            "/window/height", 
+                                            NULL,
+                                            1,
+                                            G_MAXINT16,
+                                            420,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:minimized:
@@ -769,12 +836,27 @@ parole_conf_class_init (ParoleConfClass *klass)
      * If Parole should start minimized.
      **/
     g_object_class_install_property (object_class,
-                                     PROP_MINIMIZED,
+                                     PROP_WINDOW_MINIMIZED,
                                      g_param_spec_boolean ("minimized",
-                                                           "/window/minimized", 
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                            "/window/minimized", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
+                                            
+    /**
+     * ParoleConf:maximized:
+     *
+     * Xfconf property: /window/maximized
+     * 
+     * If Parole should start maximized.
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_WINDOW_MINIMIZED,
+                                     g_param_spec_boolean ("window-maximized",
+                                            "/window/maximized", 
+                                            NULL,
+                                            FALSE,
+                                            G_PARAM_READWRITE));
 
     /**
      * ParoleConf:window-width:
@@ -786,12 +868,12 @@ parole_conf_class_init (ParoleConfClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_WINDOW_WIDTH,
                                      g_param_spec_int ("window-width",
-                                                       "/window/width", 
-                                                       NULL,
-                                                       1,
-                                                       G_MAXINT16,
-                                                       760,
-                                                       G_PARAM_READWRITE));
+                                            "/window/width", 
+                                            NULL,
+                                            1,
+                                            G_MAXINT16,
+                                            760,
+                                            G_PARAM_READWRITE));
 
 }
 
@@ -908,7 +990,7 @@ parole_conf_init (ParoleConf *conf)
 
         /* set the string we check */
         if (!xfconf_channel_has_property (conf->channel, check_prop))
-        xfconf_channel_set_string (conf->channel, check_prop, "Sans Bold 20");
+            xfconf_channel_set_string (conf->channel, check_prop, "Sans Bold 20");
     }
 
     conf->property_changed_id =
@@ -971,9 +1053,9 @@ parole_conf_write_entry_list (ParoleConf *conf, const gchar *name, gchar **value
         if (value[i] && g_strcmp0(value[i], "") != 0 && g_strcmp0(value[i], "none") != 0 )
         {
             if (count == 0)
-            value_string = g_strdup(value[i]);
+                value_string = g_strdup(value[i]);
             else
-            value_string = g_strconcat (value_string, ";", value[i], NULL);
+                value_string = g_strconcat (value_string, ";", value[i], NULL);
             count++;
         }
     }
