@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -46,42 +46,46 @@
 /*
  * GtkBuilder Callbacks
  */
-void    parole_media_chooser_add_clicked (GtkWidget *widget,
-					  ParoleMediaChooser *chooser);
+void    parole_media_chooser_add_clicked    (GtkWidget *widget,
+                                             ParoleMediaChooser *chooser);
 
-void    parole_media_chooser_close_clicked (GtkWidget *widget,
-					    ParoleMediaChooser *chooser);
+void    parole_media_chooser_close_clicked  (GtkWidget *widget,
+                                             ParoleMediaChooser *chooser);
 
-void	parole_media_chooser_destroy_cb (GtkWidget *widget,
-					 ParoleMediaChooser *chooser);
-					 
-void	media_chooser_folder_changed_cb (GtkWidget *widget, 
-					 ParoleMediaChooser *chooser);
+void    parole_media_chooser_destroy_cb     (GtkWidget *widget,
+                                             ParoleMediaChooser *chooser);
+                     
+void    media_chooser_folder_changed_cb     (GtkWidget *widget, 
+                                             ParoleMediaChooser *chooser);
 
-void	media_chooser_file_activate_cb  (GtkFileChooser *filechooser,
-					 ParoleMediaChooser *chooser);
+void    media_chooser_file_activate_cb      (GtkFileChooser *filechooser,
+                                             ParoleMediaChooser *chooser);
 
 struct ParoleMediaChooser
 {
     GObject             parent;
     
-    ParoleConf          *conf;
-    GtkWidget			*window;
-    GtkWidget 			*spinner;
+    ParoleConf         *conf;
+    GtkWidget          *window;
+    GtkWidget          *spinner;
     
 };
 
 struct ParoleMediaChooserClass
 {
-    GObjectClass 		 parent_class;
+    GObjectClass        parent_class;
     
-    void			 (*media_files_opened)		    (ParoleMediaChooser *chooser,
-								     GSList *list);
+    void                (*media_files_opened)   (ParoleMediaChooser *chooser,
+                                                 GSList *list);
+                                                 
+    void                (*iso_opened)           (ParoleMediaChooser *chooser,
+                                                 gchar *filename);
 };
 
 enum
 {
     MEDIA_FILES_OPENED,
+    ISO_OPENED,
     LAST_SIGNAL
 };
 
@@ -97,10 +101,10 @@ media_chooser_folder_changed_cb (GtkWidget *widget, ParoleMediaChooser *chooser)
     
     if ( folder )
     {
-    g_object_set (G_OBJECT (chooser->conf),
-		  "media-chooser-folder", folder,
-		  NULL);
-	g_free (folder);
+        g_object_set (G_OBJECT (chooser->conf),
+                      "media-chooser-folder", folder,
+                      NULL);
+        g_free (folder);
     }
 }
 
@@ -120,18 +124,33 @@ parole_media_chooser_add (ParoleMediaChooser *chooser, GtkWidget *file_chooser)
     filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (file_chooser));
     
     if ( G_UNLIKELY (files == NULL) )
-	return;
-	
-	g_object_get (G_OBJECT (chooser->conf),
-		  "scan-recursive", &scan_recursive,
-		  NULL);
+        return;
+    
+    g_object_get (G_OBJECT (chooser->conf),
+                  "scan-recursive", &scan_recursive,
+                  NULL);
     
     len = g_slist_length (files);
     
     for ( i = 0; i < len; i++)
     {
-	file = g_slist_nth_data (files, i);
-	parole_get_media_files (filter, file, scan_recursive, &media_files);
+        file = g_slist_nth_data (files, i);
+        if (g_str_has_suffix(file, ".iso"))
+        {
+            // FIXME: Is there some way to add the ISO to the playlist?
+            // For now we will play the ISO if it is the first file found, otherwise ignore.
+            if (g_slist_length(media_files) != 0)
+                continue;
+            g_signal_emit (G_OBJECT (chooser), signals [ISO_OPENED], 0, file);
+            
+            g_slist_free (media_files);
+    
+            g_slist_foreach (files, (GFunc) g_free, NULL);
+            g_slist_free (files);
+            
+            return;
+        }
+        parole_get_media_files (filter, file, scan_recursive, &media_files);
     }
     
     g_signal_emit (G_OBJECT (chooser), signals [MEDIA_FILES_OPENED], 0, media_files);
@@ -161,7 +180,7 @@ parole_media_chooser_add_idle (gpointer data)
 static void
 parole_media_chooser_open (ParoleMediaChooser *chooser)
 {
-    parole_window_busy_cursor (chooser->window->window);
+    parole_window_busy_cursor (gtk_widget_get_window(GTK_WIDGET(chooser->window)));
 
     gtk_widget_show( chooser->spinner );
     
@@ -192,10 +211,10 @@ void media_chooser_file_activate_cb (GtkFileChooser *filechooser, ParoleMediaCho
 static void
 parole_media_chooser_open_internal (ParoleMediaChooser *media_chooser)
 {
-    GtkWidget       *file_chooser;
-    GtkBuilder      *builder;
-    GtkWidget       *recursive;
-    GtkFileFilter   *filter, *audio_filter, *video_filter, *playlist_filter, *all_files;
+    GtkWidget      *file_chooser;
+    GtkBuilder     *builder;
+    GtkWidget      *recursive;
+    GtkFileFilter  *filter, *audio_filter, *video_filter, *playlist_filter, *all_files;
     gboolean        scan_recursive;
     gboolean        replace_playlist;
     gboolean        play;
@@ -231,20 +250,20 @@ parole_media_chooser_open_internal (ParoleMediaChooser *media_chooser)
 
     /* Set the folder that is shown */
     g_object_get (G_OBJECT (media_chooser->conf),
-		  "media-chooser-folder", &folder,
-		  NULL);
+                  "media-chooser-folder", &folder,
+                  NULL);
     
     if ( folder )
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_chooser), folder);
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_chooser), folder);
     
     gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (file_chooser), TRUE);
 
     /* Get playlist-properties to load files accordingly */
     g_object_get (G_OBJECT (media_chooser->conf),
-		  "scan-recursive", &scan_recursive,
-		  "replace-playlist", &replace_playlist,
-		  "play-opened-files", &play,
-		  NULL);
+                  "scan-recursive", &scan_recursive,
+                  "replace-playlist", &replace_playlist,
+                  "play-opened-files", &play,
+                  NULL);
     
     recursive = GTK_WIDGET (gtk_builder_get_object (builder, "recursive"));
     
@@ -266,7 +285,7 @@ parole_media_chooser_finalize (GObject *object)
     g_object_unref (chooser->conf);
     
     if ( chooser->window )
-	gtk_widget_destroy (chooser->window);
+        gtk_widget_destroy (chooser->window);
     
     G_OBJECT_CLASS (parole_media_chooser_parent_class)->finalize (object);
 }
@@ -277,14 +296,24 @@ parole_media_chooser_class_init (ParoleMediaChooserClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
     signals[MEDIA_FILES_OPENED] = 
-        g_signal_new("media-files-opened",
-                      PAROLE_TYPE_MEDIA_CHOOSER,
-                      G_SIGNAL_RUN_LAST,
-                      G_STRUCT_OFFSET (ParoleMediaChooserClass, media_files_opened),
-                      NULL, NULL,
-		      g_cclosure_marshal_VOID__POINTER,
-                      G_TYPE_NONE, 1, 
-		      G_TYPE_POINTER);
+        g_signal_new   ("media-files-opened",
+                        PAROLE_TYPE_MEDIA_CHOOSER,
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET (ParoleMediaChooserClass, media_files_opened),
+                        NULL, NULL,
+                        g_cclosure_marshal_VOID__POINTER,
+                        G_TYPE_NONE, 1, 
+                        G_TYPE_POINTER);
+                        
+    signals[ISO_OPENED] = 
+        g_signal_new   ("iso-opened",
+                        PAROLE_TYPE_MEDIA_CHOOSER,
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET (ParoleMediaChooserClass, iso_opened),
+                        NULL, NULL,
+                        g_cclosure_marshal_VOID__POINTER,
+                        G_TYPE_NONE, 1, 
+                        G_TYPE_POINTER);
 
     object_class->finalize = parole_media_chooser_finalize;
 }
@@ -306,8 +335,8 @@ ParoleMediaChooser *parole_media_chooser_open_local (GtkWidget *parent)
     gtk_window_set_modal (GTK_WINDOW (chooser->window), TRUE);
     
     if ( parent )
-	gtk_window_set_transient_for (GTK_WINDOW (chooser->window), GTK_WINDOW (parent));
-	
+        gtk_window_set_transient_for (GTK_WINDOW (chooser->window), GTK_WINDOW (parent));
+    
     gtk_window_set_position (GTK_WINDOW (chooser->window), GTK_WIN_POS_CENTER_ON_PARENT);
 
     gtk_widget_show_all (chooser->window);
