@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -40,18 +40,17 @@ static void parole_open_location_finalize   (GObject *object);
 
 struct ParoleOpenLocation
 {
-    GObject         	parent;
+    GObject             parent;
     
-    
-    GtkWidget 	       *entry;
+    GtkWidget          *entry;
 };
 
 struct ParoleOpenLocationClass
 {
-    GObjectClass 	parent_class;
+    GObjectClass    parent_class;
     
-    void		(*location_opened)	(ParoleOpenLocation *self,
-						 const gchar *address);
+    void            (*location_opened)  (ParoleOpenLocation *self,
+                                         const gchar *address);
 };
 
 enum
@@ -81,19 +80,19 @@ parole_open_location_response_cb (GtkDialog *dialog, gint response_id, ParoleOpe
 
     if ( response_id == GTK_RESPONSE_OK )
     {
-	location = gtk_combo_box_text_get_active_text  (GTK_COMBO_BOX_TEXT(self->entry));
-	
-	if ( !location || strlen (location) == 0)
-	    goto out;
+        location = gtk_combo_box_text_get_active_text  (GTK_COMBO_BOX_TEXT(self->entry));
+        
+        if ( !location || strlen (location) == 0)
+            goto out;
 
-	TRACE ("Location %s", location);
+        TRACE ("Location %s", location);
 
-	gtk_widget_hide (GTK_WIDGET (dialog));
-	g_signal_emit (G_OBJECT (self), signals [LOCATION_OPENED], 0, location);
+        gtk_widget_hide (GTK_WIDGET (dialog));
+        g_signal_emit (G_OBJECT (self), signals [LOCATION_OPENED], 0, location);
     }
 
-    out:
-	gtk_widget_destroy (GTK_WIDGET (dialog));
+out:
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 /* Populate the history-popup */
@@ -105,24 +104,24 @@ parole_open_location_get_completion_model (void)
     gchar **lines = NULL;
     guint i;
     
-    store = gtk_list_store_new (N_COLS, GTK_TYPE_STRING);
+    store = gtk_list_store_new (N_COLS, G_TYPE_STRING);
     
     lines = parole_get_history ();
     
     if ( lines )
     {
-	for ( i = 0; lines[i]; i++)
-	{
-	    if ( g_strcmp0(lines[i], "") != 0 )
-	    {
-	    gtk_list_store_append (store, &iter);
-	    gtk_list_store_set (store, &iter,
-				COL_ADDRESS, lines [i],
-				-1);
+        for ( i = 0; lines[i]; i++)
+        {
+            if ( g_strcmp0(lines[i], "") != 0 )
+            {
+                gtk_list_store_append (store, &iter);
+                gtk_list_store_set (store, &iter,
+                                    COL_ADDRESS, lines [i],
+                                    -1);
+            }
         }
-	}
-	
-	g_strfreev (lines);
+        
+        g_strfreev (lines);
     }
     return GTK_TREE_MODEL (store);
 }
@@ -178,8 +177,8 @@ ParoleOpenLocation *parole_open_location (GtkWidget *parent)
     dialog = GTK_WIDGET (gtk_builder_get_object (builder, "open-location"));
     
     if ( parent )
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
-	
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
+    
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     
     self->entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry"));
@@ -190,14 +189,14 @@ ParoleOpenLocation *parole_open_location (GtkWidget *parent)
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
     g_signal_connect_swapped (gtk_builder_get_object (builder, "clear-history"), "clicked",
-			      G_CALLBACK (parole_open_location_clear_history), model);
+                              G_CALLBACK (parole_open_location_clear_history), model);
     gtk_widget_set_tooltip_text (GTK_WIDGET (gtk_builder_get_object (builder, "clear-history")), _("Clear History"));
     
     g_signal_connect (dialog, "delete-event",
-		      G_CALLBACK (gtk_widget_destroy), NULL);
-		      
+                      G_CALLBACK (gtk_widget_destroy), NULL);
+              
     g_signal_connect (dialog, "response",
-		      G_CALLBACK (parole_open_location_response_cb), self);
+                      G_CALLBACK (parole_open_location_response_cb), self);
     
     gtk_widget_show_all (dialog);
     g_object_unref (builder);
