@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -30,6 +30,7 @@
 
 #include <src/misc/parole-provider-player.h>
 
+#include "parole-dbus.h"
 #include "parole-plugin-player.h"
 #include "parole-plugins-manager.h"
 #include "parole-medialist.h"
@@ -50,12 +51,29 @@ struct ParolePluginPlayerPrivate
     
     gulong state_changed;
     gulong tag_message;
+    gulong seeked;
     gboolean packed;
+    
+    gboolean fullscreen;
 
 };
 
 G_DEFINE_TYPE_WITH_CODE (ParolePluginPlayer, parole_plugin_player, G_TYPE_OBJECT,
-    G_IMPLEMENT_INTERFACE (PAROLE_TYPE_PROVIDER_PLAYER, parole_plugin_player_iface_init))
+                         G_IMPLEMENT_INTERFACE (PAROLE_TYPE_PROVIDER_PLAYER, parole_plugin_player_iface_init))
+                         
+static void
+parole_plugin_player_send_message (const gchar *message)
+{
+    DBusGProxy *proxy;
+    
+    proxy = parole_get_proxy (PAROLE_DBUS_PATH, PAROLE_DBUS_INTERFACE);
+    
+    dbus_g_proxy_call_no_reply (proxy, message,
+                                G_TYPE_INVALID,
+                                G_TYPE_INVALID);
+    
+    g_object_unref (proxy);
+}
 
 static GtkWidget *
 parole_plugin_player_get_main_window (ParoleProviderPlayer *provider)
@@ -68,7 +86,7 @@ parole_plugin_player_get_main_window (ParoleProviderPlayer *provider)
 
 static void
 parole_plugin_player_pack_widget (ParoleProviderPlayer *provider, GtkWidget *widget, 
-				  const gchar *title, ParolePluginContainer container_type)
+                                  const gchar *title, ParolePluginContainer container_type)
 {
     ParolePluginPlayer *player;
     ParolePluginsManager *manager;
@@ -104,19 +122,20 @@ parole_plugin_player_get_stream (ParoleProviderPlayer *provider)
     return parole_gst_get_stream (PAROLE_GST (player->priv->gst));
 }
 
-static gboolean	
+static gboolean 
 parole_plugin_player_play_uri (ParoleProviderPlayer *provider, const gchar *uri)
 {
-    ParolePluginPlayer *player;
+    ParoleMediaList *list;
+
+    list = PAROLE_MEDIA_LIST (parole_media_list_get ());
+    parole_media_list_open_uri (list, uri);
     
-    player = PAROLE_PLUGIN_PLAYER (provider);
-    
-    parole_gst_play_uri (PAROLE_GST (player->priv->gst), uri, NULL);
+    g_object_unref (list);
     
     return TRUE;
 }
 
-static gboolean	
+static gboolean 
 parole_plugin_player_pause (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
@@ -128,7 +147,7 @@ parole_plugin_player_pause (ParoleProviderPlayer *provider)
     return TRUE;
 }
 
-static gboolean	
+static gboolean 
 parole_plugin_player_resume (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
@@ -140,7 +159,7 @@ parole_plugin_player_resume (ParoleProviderPlayer *provider)
     return TRUE;
 }
 
-static gboolean	
+static gboolean 
 parole_plugin_player_stop (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
@@ -152,7 +171,23 @@ parole_plugin_player_stop (ParoleProviderPlayer *provider)
     return TRUE;
 }
 
-static gboolean	
+static gboolean 
+parole_plugin_player_play_previous (ParoleProviderPlayer *provider)
+{
+    parole_plugin_player_send_message ("PrevTrack");
+    
+    return TRUE;
+}
+
+static gboolean 
+parole_plugin_player_play_next (ParoleProviderPlayer *provider)
+{
+    parole_plugin_player_send_message ("NextTrack");
+    
+    return TRUE;
+}
+
+static gboolean 
 parole_plugin_player_seek (ParoleProviderPlayer *provider, gdouble pos)
 {
     ParolePluginPlayer *player;
@@ -164,6 +199,20 @@ parole_plugin_player_seek (ParoleProviderPlayer *provider, gdouble pos)
     return TRUE;
 }
 
+static gdouble
+parole_plugin_player_get_stream_position (ParoleProviderPlayer *provider)
+{
+    ParolePluginPlayer *player;
+    gdouble position = 0;
+    
+    player = PAROLE_PLUGIN_PLAYER (provider);
+
+    position = parole_gst_get_stream_position (PAROLE_GST (player->priv->gst));
+    
+    /* Return as microseconds */
+    return position*1000000.0;
+}
+
 static void parole_plugin_player_open_media_chooser (ParoleProviderPlayer *provider)
 {
     ParoleMediaList *list;
@@ -174,6 +223,34 @@ static void parole_plugin_player_open_media_chooser (ParoleProviderPlayer *provi
     g_object_unref (list);
 }
 
+static GtkAction* parole_plugin_player_get_action (ParoleProviderPlayer *provider, ParolePlayerAction action)
+{
+    return parole_player_get_action (action);
+}
+
+static gboolean parole_plugin_player_get_fullscreen (ParoleProviderPlayer *provider)
+{
+    ParolePluginPlayer *player;
+    
+    player = PAROLE_PLUGIN_PLAYER (provider);
+    
+    return player->priv->fullscreen;
+}
+
+static gboolean parole_plugin_player_set_fullscreen (ParoleProviderPlayer *provider, gboolean fullscreen)
+{
+    GtkWidget *window;
+    
+    window = parole_plugin_player_get_main_window (provider);
+    
+    if (fullscreen)
+        gtk_window_fullscreen(GTK_WINDOW(window));
+    else
+        gtk_window_unfullscreen(GTK_WINDOW(window));
+        
+    return TRUE;
+}
+
 static void parole_plugin_player_iface_init (ParoleProviderPlayerIface *iface)
 {
     iface->get_main_window = parole_plugin_player_get_main_window;
@@ -184,13 +261,19 @@ static void parole_plugin_player_iface_init (ParoleProviderPlayerIface *iface)
     iface->pause = parole_plugin_player_pause;
     iface->resume = parole_plugin_player_resume;
     iface->stop = parole_plugin_player_stop;
+    iface->play_previous = parole_plugin_player_play_previous;
+    iface->play_next = parole_plugin_player_play_next;
     iface->seek = parole_plugin_player_seek;
+    iface->get_stream_position = parole_plugin_player_get_stream_position;
     iface->open_media_chooser = parole_plugin_player_open_media_chooser;
+    iface->get_action = parole_plugin_player_get_action;
+    iface->get_fullscreen = parole_plugin_player_get_fullscreen;
+    iface->set_fullscreen = parole_plugin_player_set_fullscreen;
 }
 
 static void 
 parole_plugin_player_media_state_changed_cb (ParoleGst *gst, const ParoleStream *stream, 
-					     ParoleState state, ParolePluginPlayer *player)
+                                             ParoleState state, ParolePluginPlayer *player)
 {
     g_signal_emit_by_name (G_OBJECT (player), "state-changed", stream, state);
 }
@@ -201,6 +284,24 @@ parole_plugin_player_media_tag_cb (ParoleGst *gst, const ParoleStream *stream, P
     g_signal_emit_by_name (G_OBJECT (player), "tag-message", stream);
 }
 
+static void
+parole_plugin_player_media_seeked_cb (ParoleGst *gst, ParolePluginPlayer *player)
+{
+    g_signal_emit_by_name (G_OBJECT (player), "seeked");
+}
+
+static gboolean
+parole_plugin_player_window_state_event  (GtkWidget *widget, 
+                                          GdkEventWindowState *event,
+                                          ParolePluginPlayer *player)
+{
+    if (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN)
+        player->priv->fullscreen = TRUE;
+    else
+        player->priv->fullscreen = FALSE;
+    return FALSE;
+}
+
 static void
 parole_plugin_player_class_init (ParolePluginPlayerClass *klass)
 {
@@ -214,15 +315,26 @@ parole_plugin_player_class_init (ParolePluginPlayerClass *klass)
 static void
 parole_plugin_player_init (ParolePluginPlayer *player)
 {
+    GtkWidget *window;
     player->priv = PAROLE_PLUGIN_PLAYER_GET_PRIVATE (player);
     
     player->priv->gst = parole_gst_get ();
     
     player->priv->state_changed = g_signal_connect (G_OBJECT (player->priv->gst), "media-state",
-					    G_CALLBACK (parole_plugin_player_media_state_changed_cb), player);
-		      
+                        G_CALLBACK (parole_plugin_player_media_state_changed_cb), player);
+              
     player->priv->tag_message = g_signal_connect (G_OBJECT (player->priv->gst), "media-tag",
-					  G_CALLBACK (parole_plugin_player_media_tag_cb), player);
+                        G_CALLBACK (parole_plugin_player_media_tag_cb), player);
+                        
+    player->priv->seeked = g_signal_connect (G_OBJECT (player->priv->gst), "media-seeked",
+                        G_CALLBACK (parole_plugin_player_media_seeked_cb), player);
+
+    player->priv->fullscreen = FALSE;                        
+    window = GTK_WIDGET(gtk_widget_get_toplevel (player->priv->gst));
+    g_signal_connect(   G_OBJECT(window), 
+                        "window-state-event", 
+                        G_CALLBACK(parole_plugin_player_window_state_event), 
+                        player );
 
     player->priv->packed = FALSE;
     player->priv->box = NULL;
@@ -237,15 +349,18 @@ parole_plugin_player_finalize (GObject *object)
     
     if ( G_IS_OBJECT (player->priv->gst) )
     {
-	if (g_signal_handler_is_connected (player->priv->gst, player->priv->state_changed)) 
-	    g_signal_handler_disconnect (player->priv->gst, player->priv->state_changed);
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->state_changed)) 
+            g_signal_handler_disconnect (player->priv->gst, player->priv->state_changed);
 
-	if (g_signal_handler_is_connected (player->priv->gst, player->priv->tag_message)) 
-	    g_signal_handler_disconnect (player->priv->gst, player->priv->tag_message);
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->tag_message)) 
+            g_signal_handler_disconnect (player->priv->gst, player->priv->tag_message);
+            
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->seeked)) 
+            g_signal_handler_disconnect (player->priv->gst, player->priv->seeked);
     }
     
     if ( player->priv->packed && GTK_IS_WIDGET (player->priv->box))
-	gtk_widget_destroy (player->priv->box);
+        gtk_widget_destroy (player->priv->box);
 
     G_OBJECT_CLASS (parole_plugin_player_parent_class)->finalize (object);
 }
