@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -104,7 +104,7 @@ static void parole_plugins_manager_set_property    (GObject *object,
 struct ParolePluginsManagerPrivate
 {
     GtkWidget *list_nt;
-    GtkWidget *main_nt;
+    GtkWidget *main_window;
     
     GPtrArray *array;
     
@@ -166,6 +166,13 @@ parole_plugins_manager_get_selected_module_data (PrefData *pref, ParoleProviderM
     GtkTreeIter       iter;
 
     sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (pref->view));
+    
+    if ( !sel )
+    {
+        *module = NULL;
+        *info = NULL;
+        return;
+    }
 
     if ( !gtk_tree_selection_get_selected (sel, &model, &iter))
     {
@@ -242,39 +249,47 @@ parole_plugins_manager_cell_toggled_cb (GtkCellRendererToggle *cell_renderer,
                                         gchar *path_str, 
                                         PrefData *pref)
 {
-    ParoleProviderModule *module;
+    ParoleProviderModule *module = NULL;
     GtkTreeIter iter;
     GtkTreePath *path;
-    gboolean active;
+    gboolean active = FALSE;
 
     path = gtk_tree_path_new_from_string (path_str);
 
-    gtk_tree_model_get_iter (GTK_TREE_MODEL (pref->store), &iter, path);
-
-    gtk_tree_model_get (GTK_TREE_MODEL (pref->store), &iter, 
-                        COL_ACTIVE, &active, 
-                        COL_MODULE, &module,
-                        -1);
-
-    active ^= 1;
-
-    if ( pref->manager->priv->load_plugins )
+    if (gtk_tree_model_get_iter (GTK_TREE_MODEL (pref->store), &iter, path))
     {
-        if ( active )
-        {
-            g_type_module_use (G_TYPE_MODULE (module));
-            parole_provider_module_new_plugin (module);
-        }
-        else
-        {
-            parole_provider_module_free_plugin (module);
-            g_type_module_unuse (G_TYPE_MODULE (module));
-        }
-    }
+        gtk_tree_model_get (GTK_TREE_MODEL (pref->store), &iter, 
+                            COL_ACTIVE, &active, 
+                            COL_MODULE, &module,
+                            -1);
 
-    gtk_list_store_set (GTK_LIST_STORE (pref->store), &iter, 
-                        COL_ACTIVE, active,
-                        -1);
+        active ^= 1;
+
+        if ( pref->manager->priv->load_plugins )
+        {
+            if ( active )
+            {
+                g_type_module_use (G_TYPE_MODULE (module));
+                if (!parole_provider_module_new_plugin (module))
+                {
+                    // If plugin loading fails...
+                    parole_dialog_error(GTK_WINDOW(pref->window), _("Plugin failed to load"), _("Please check your installation"));
+                    parole_provider_module_free_plugin (module);
+                    g_type_module_unuse (G_TYPE_MODULE (module));
+                    active = FALSE;
+                }
+            }
+            else
+            {
+                parole_provider_module_free_plugin (module);
+                g_type_module_unuse (G_TYPE_MODULE (module));
+            }
+        }
+
+        gtk_list_store_set (GTK_LIST_STORE (pref->store), &iter, 
+                            COL_ACTIVE, active,
+                            -1);
+    }
 
     gtk_tree_path_free (path);
 
@@ -389,9 +404,9 @@ parole_plugins_manager_show_plugins_pref (GtkWidget *widget, ParolePluginsManage
     /*No plugins found*/
     if ( manager->priv->array->len == 0 )
     {
-        parole_dialog_info (GTK_WINDOW (gtk_widget_get_toplevel (manager->priv->main_nt)),
+        parole_dialog_info (GTK_WINDOW (manager->priv->main_window),
         _("No installed plugins found on this system"),
-        _("No installed plugins found on this system")); 
+        _("Please check your installation.")); 
         return;
     }
 
@@ -411,7 +426,7 @@ parole_plugins_manager_show_plugins_pref (GtkWidget *widget, ParolePluginsManage
     pref->configure = GTK_WIDGET (gtk_builder_get_object (builder, "configure"));
 
     gtk_window_set_transient_for (GTK_WINDOW (pref->window), 
-    GTK_WINDOW (gtk_widget_get_toplevel (manager->priv->main_nt)));
+    GTK_WINDOW (manager->priv->main_window));
 
     for ( i = 0; i < manager->priv->array->len; i++)
     {
@@ -603,7 +618,7 @@ parole_plugins_manager_init (ParolePluginsManager *manager)
     manager->priv->load_plugins = TRUE;
 
     manager->priv->list_nt = GTK_WIDGET (gtk_builder_get_object (builder, "notebook-playlist"));
-    manager->priv->main_nt = GTK_WIDGET (gtk_builder_get_object (builder, "main-notebook"));
+    manager->priv->main_window = GTK_WIDGET (gtk_builder_get_object (builder, "main-window"));
 
     manager->priv->conf = parole_conf_new();
 
@@ -613,17 +628,10 @@ parole_plugins_manager_init (ParolePluginsManager *manager)
     g_signal_connect   (manager->priv->list_nt, "page-removed",
                         G_CALLBACK (parole_plugins_manager_page_removed_cb), NULL);
 
-    g_signal_connect   (manager->priv->main_nt, "page-added",
-                        G_CALLBACK (parole_plugins_manager_page_added_cb), NULL);
-
-    g_signal_connect   (manager->priv->main_nt, "page-removed",
-                        G_CALLBACK (parole_plugins_manager_page_removed_cb), NULL);
-
     g_signal_connect   (gtk_builder_get_object (builder, "plugins-menu-item"), "activate",
                         G_CALLBACK (parole_plugins_manager_show_plugins_pref), manager);
 
     parole_plugins_manager_set_show_tabs (GTK_NOTEBOOK (manager->priv->list_nt));
-    parole_plugins_manager_set_show_tabs (GTK_NOTEBOOK (manager->priv->main_nt));
 
     g_object_unref (builder);
 }
@@ -728,9 +736,4 @@ parole_plugins_manager_pack (ParolePluginsManager *manager, GtkWidget *widget, c
         gtk_notebook_append_page (GTK_NOTEBOOK (manager->priv->list_nt), widget, gtk_label_new (title));
         gtk_widget_show_all (widget);
     }
-    else if ( container == PAROLE_PLUGIN_CONTAINER_MAIN_VIEW )
-    {
-        gtk_notebook_append_page (GTK_NOTEBOOK (manager->priv->main_nt), widget, gtk_label_new (title));
-        gtk_widget_show_all (widget);
-    }
 }
